Structs
Statics
Functions
- check_
database_ file_ is_ valid_ or_ create_ database_ file - get_
config - get_
config_ path - get_
main_ cal_ lang_ pair - get_
second_ cal_ lang_ pair - move_
database - open_
database - read_
config_ file_ or_ save_ default_ config_ file - reload_
config_ file - save_
config - set_
config - set_
database_ file - check if the new filepath exists or not if exists, it should be a valid database and we only switch to it. if the path don’t exists, we will move our database to that location.
- set_
items_ display_ direction_ config - set_
main_ cal_ config - set_
secondary_ cal_ config