Function set_database_file

pub fn set_database_file(filepath: String) -> Result<(), Error>
check if the new filepath exists or not if exists, it should be a valid database and we only switch to it. if the path don’t exists, we will move our database to that location.